#! /bin/bash
# build-kernels is copyrighted by Vaughan Agrez
# build-kernels is released under GPL licence (version 2)
# AUTHOR: Vaughan Agrez
# EMAIL: ocilent1@gmail.com

###
# Defines
###
#VERSION=0.2.5
VERSION=0.2.8
# change for 3.x, by AS
NAME="Build Kernels"
NAMEL=build-kernels
NAVER="$NAME ($VERSION)"
KSPEC=../SPECS/kernel-pclos.spec
LOGFILE=$NAMEL.log
LOGDIR=../BUILD
LOG=$LOGDIR/$LOGFILE
ARCH=$(arch)
#ARCH=x86_64
#Messages
SPECWARN="Can not find $KSPEC.
You require a correctly named spec file to run this build script.

Exiting the build process"
NOBUILD="You chose not to build any kernels"
FINBUILD="Finished the kernel build process"

#kernel descriptions
if test "$ARCH" = "x86_64"; then
    DESCR_DEF="Default x86_64 linux kernel"
    DESCR_SERVER="x86_64 linux kernel for servers"
    DESCR_LINUS="x86_64 'linus' linux kernel (no 3rd party patches)"
    DESCR_K8="x86_64 AMD64 (K8) optimised kernel"
    DESCR_BFS="x86_64 kernel patched with BFS scheduler"
else
    DESCR_DEF="i686 kernel (4GB HIGHMEM)"
    DESCR_SERVER="i686 (pae enabled) server kernel (64GB PAE)"
    DESCR_K8="AMD64 (K8) optimised kernel (4GB HIGHMEM)"
    DESCR_LINUS="i686 linus kernel (4GB HIGHMEM)"
    DESCR_BFS="i686 kernel patched with BFS scheduler (4GB HIGHMEM)"
    DESCR_TEXSTAR="i686 (pae enabled) with BFS scheduler (64GB PAE)"
fi

###
# Functions
###

logit()
{
echo "$(date): $1" >> $LOG
}

spec_def()
{
grep "%define $1" $KSPEC |awk '{ print $3 }'
}

krelease()
{
KBASE=4
SUBLEVEL=$(spec_def 'sublevel')
STABREL=$(spec_def 'stabrel')
BUILDREL=$(spec_def 'buildrel')
KAPPEND=$(spec_def 'kappend')
RTREL=$(spec_def 'rtrel')

#if test "$STABREL" != "0"; then
	KVERSION=$KBASE.$SUBLEVEL.$STABREL-$KAPPEND$BUILDREL
	KLINUS=$KBASE.$SUBLEVEL.$STABREL
#else
#	KVERSION=$KBASE.$SUBLEVEL-$KAPPEND$BUILDREL
#	KLINUS=$KBASE.$SUBLEVEL
#fi
}

buildcmd()
{	
echo "$1" > $LOGDIR/$KERN_VERS-build.log
logit "$KERN_VERS build started"

if test "$1" = ""; then
	rpmbuild -ba $KSPEC $1 2>>$LOGDIR/$KERN_VERS-build.log
else
	rpmbuild -bb $KSPEC $1 2>>$LOGDIR/$KERN_VERS-build.log
fi

if [ "$?" != "0" ]; then
	WARN="***** WARNING: $KERN_VERS FAILED TO BUILD!*****"
	PLSCHECK="Please check $LOGDIR/$KERN_VERS-build.log for build errors"
	echo "$WARN" && logit "$WARN"
	echo "$PLSCHECK" && logit "$PLSCHECK"
else
	BELONG="all your kernels are belong to us."
	echo "$BELONG" && logit "$BELONG"
fi
}

selection()
{
QUESTION="Please select the kernel you want to build (Kernel Version: $KVERSION)"
if test "$DIALOG" = "zenity"; then
    ZEN_CMD="zenity --list --checklist --width=800 --height=270"
    if test "$ARCH" = "x86_64"; then
	SEL=`$ZEN_CMD --title "$QUESTION" --column="" --column "Kernel type" --column "Description" \
	TRUE "DEFAULT" "$DESCR_DEF" \
	FALSE "SERVER" "$DESCR_SERVER" \
	FALSE "LINUS" "$DESCR_LINUS" \
	FALSE "BFS" "$DESCR_BFS" \
	FALSE "K8" "$DESCR_K8"`
    else
	SEL=`$ZEN_CMD --title "$QUESTION" --column="" --column "Kernel type" --column "Description"\
	TRUE "DEFAULT" "$DESCR_DEF" \
	FALSE "SERVER" "$DESCR_SERVER" \
	FALSE "LINUS" "$DESCR_LINUS" \
	FALSE "K8" "$DESCR_K8" \
	FALSE "BFS" "$DESCR_BFS" \
	FALSE "TEXSTAR" "$DESCR_TEXSTAR"`
    fi
elif test "$DIALOG" = "kdialog"; then
    if test "$ARCH" = "x86_64"; then
	SEL=`kdialog --geometry 500x220 --checklist "$QUESTION" \
	"DEFAULT" "$DESCR_DEF" on \
	"SERVER" "$DESCR_SERVER" off \
	"LINUS" "$DESCR_LINUS" off \
	"K8" "$DESCR_K8" off \
	"BFS" "$DESCR_BFS" off`
    else
	SEL=`kdialog --geometry 500x220 --checklist "$QUESTION" \
	"DEFAULT" "$DESCR_DEF" on \
	"SERVER" "$DESCR_SERVER" off \
	"LINUS" "$DESCR_LINUS" off \
	"K8" "$DESCR_K8" off \
	"BFS" "$DESCR_BFS" off \
 	"TEXSTAR" "$DESCR_TEXSTAR" off`
    fi
elif test "$DIALOG" = "dialog"; then
    if test "$ARCH" = "x86_64"; then
	dialog --checklist "$QUESTION" 0 0 0 \
	"DEFAULT" "$DESCR_DEF" ON \
	"SERVER" "$DESCR_SERVER" OFF \
	"LINUS" "$DESCR_LINUS" OFF \
	"K8" "$DESCR_K8" OFF \
	"BFS" "$DESCR_BFS" OFF 2> $LOGDIR/.tempsel
    else
	dialog --checklist "$QUESTION" 0 0 0 \
	"DEFAULT" "$DESCR_DEF" ON \
	"SERVER" "$DESCR_SERVER" OFF \
	"LINUS" "$DESCR_LINUS" OFF \
	"K8" "$DESCR_K8" OFF \
	"BFS" "$DESCR_BFS" OFF \
	"TEXSTAR" "$DESCR_TEXSTAR" OFF 2> $LOGDIR/.tempsel
    fi
	SEL=$(cat $LOGDIR/.tempsel)
	rm -f $LOGDIR/.tempsel
fi
}

buildselection()
{
logit "SELECTED BUILDS: $SEL"
if echo "$SEL" | grep 'DEFAULT' &>/dev/null; then
	KERN_VERS=kernel-$KVERSION
	buildcmd ""
fi
if echo "$SEL" | grep 'SERVER' &>/dev/null; then
	KERN_VERS=kernel-$KVERSION.pae
	buildcmd "--with server"
fi
if echo "$SEL" | grep 'LINUS' &>/dev/null; then
	KERN_VERS=kernel-$KLINUS
	buildcmd "--with linus"
fi
if echo "$SEL" | grep 'K8' &>/dev/null; then
	KERN_VERS=kernel-$KVERSION.a64
	buildcmd "--with k8"
fi
if echo "$SEL" | grep 'BFS' &>/dev/null; then
	KERN_VERS=kernel-$KVERSION.bfs
	buildcmd "--with bfs"
fi
if echo "$SEL" | grep 'TEXSTAR' &>/dev/null; then
	KERN_VERS=kernel-$KVERSION.pae.bfs
	buildcmd "--with bfs_pae"
fi
if test "$SEL" = ""; then
	logit "NO KERNELS SELECTED!"
else
	logit "$FINBUILD"
fi
echo "**************" >> $LOG
echo "" >> $LOG
}

def_dialog()
{
#don't use zenity or kdialog if X is not running!
if [ -z "$DISPLAY" ] ; then
	if [ -f /usr/bin/dialog ]; then
		echo "**Found dialog**"
		DIALOG=dialog
	else
		DIALOG=0
	fi
else
	if [ -f /usr/bin/zenity ]; then
		echo "**Found zenity**"
		DIALOG=zenity 
	elif [ -f /usr/bin/kdialog ]; then
		echo "**Found kdialog**"
		DIALOG=kdialog
	elif [ -f /usr/bin/dialog ]; then
		echo "**Found dialog**"
		DIALOG=dialog
	else
		DIALOG=0
		if test "$SEL" = ""; then
		echo ""
		echo "Zenity, kdialog or dialog can not be found!"
		echo "Please manually specify the kernel build type via"
		echo "the command line or install either zenity, kdialog"
		echo "or dialog for a GUI based kernel build selection dialog"
		fi
	fi
fi
}


dialog_err()
{
if test "$DIALOG" = "zenity"; then
	zenity --error --title "$NAVER" --text $"$1"
elif test "$DIALOG" = "kdialog"; then
	kdialog --error "$1" --title "$NAVER"
elif test "$DIALOG" = "dialog"; then
	dialog --title "$NAVER" --msgbox "$1" 0 0
elif test "$DIALOG" = "0"; then
	echo ""
	echo "*** ATTENTION ***"
	echo "$1"
fi
}

dialog_info()
{
if test "$DIALOG" = "zenity"; then
	zenity --info --title "$NAVER" --text $"$1"
elif test "$DIALOG" = "kdialog"; then
	kdialog --msgbox "$1" --title "$NAVER"
elif test "$DIALOG" = "dialog"; then
	dialog --title "$NAVER" --msgbox "$1" 0 0
elif test "$DIALOG" = "0"; then
	echo ""
	echo "$1"
fi
}

depends()
{
if [ ! -f $KSPEC ]; then
	dialog_err "$SPECWARN"
	exit 1
fi
}

goodbye()
{
if test "$SEL" = ""; then
	dialog_info "$NOBUILD"
else
	echo "$FINBUILD"
fi
exit 0	
}

buildhelp()
{
    echo ""
    echo "	USAGE: $0 [--build <kernel-type> | --build-all | --version ]"
    echo ""
    echo "	--build <kernel-type>: build only the selected kernel type"
    if test "$ARCH" = "x86_64"; then
	echo "	  (Avaliable kernel types are: DEFAULT, SERVER, LINUS, K8, BFS)"
    else
	echo "	  (Avaliable kernel types are: DEFAULT, SERVER, LINUS, K8, BFS, TEXSTAR)"
    fi
    echo "	--build-all: build all available kernel types"
    echo "	--version: (-v) show script version information"
    echo "	--help: (-h) show this help message"
    echo ""
    echo "	**Passing no build options also lets you select individual kernel builds**"
    echo ""
    echo ""
}

version()
{
echo ""
echo "$NAME -- Version $VERSION"
echo "AUTHOR: ocilent1@gmail.com"
echo "LICENCE: GPL V2"
echo ""
}

main()
{
def_dialog
depends
krelease
echo "**************" > $LOG
logit "$NAVER"
logit "KERNEL RELEASE: $ARCH $KVERSION"
if test "$SEL" = ""; then
	selection
fi
buildselection
goodbye
}




###
# Main
###

case $1 in
"--build" )
	SEL="`echo $@ | sed -e 's/--build //'`"
	main
	;;
"--build-all" )
	if test "$ARCH" = "x86_64"; then
	    SEL="DEFAULT SERVER LINUS K8 BFS"
	else
	    SEL="DEFAULT SERVER LINUS K8 BFS TEXSTAR"
	fi
	main
	;;
"--help" )
	buildhelp
	;;
"-h" )
	buildhelp
	;;
"--version" )
	version
	;;
"-v" )
	version
	;;
"" )
	main
	;;
esac

